checksum

Function checksum 

pub fn checksum(input: &[usize], disk_size: usize) -> String
Collect the ones count at each step_size then subtract in pairs to calculate the number of ones in each interval to give the checksum.